var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};
import * as React from "react";
import { useForm } from "../../contexts/form/form.es.js";
import { useEventListener } from "../../hooks/use-event-listener.es.js";
import { PayButton, SvgIcon } from "./ach.styles.es.js";
import { transformPlaidEventName } from "./ach.utils.es.js";
function Ach({
  accountHolderName,
  redirectURI,
  transactionId,
  callbacks,
  buttonProps,
  children,
  svgProps
}) {
  const [ach, setAch] = React.useState(() => void 0);
  const [isSubmitting, setIsSubmitting] = React.useState(false);
  const { cardTokenizeResponseReceived, payments } = useForm();
  const buttonRef = React.useRef(null);
  const handlePayment = (e) => __async(this, null, function* () {
    e.stopPropagation();
    if (!ach) {
      console.warn("ACH button was clicked, but no ACH instance was found.");
      return;
    }
    setIsSubmitting(true);
    try {
      const result = yield ach.tokenize({
        accountHolderName
      });
      if (result.status === "OK") {
        const tokenizedResult = yield cardTokenizeResponseReceived(result);
        return tokenizedResult;
      }
      let message = `Tokenization failed with status: ${result.status}`;
      if (result == null ? void 0 : result.errors) {
        message += ` and errors: ${JSON.stringify(result == null ? void 0 : result.errors)}`;
        throw new Error(message);
      }
      console.warn(message);
    } catch (error) {
      console.error(error);
    } finally {
      setIsSubmitting(false);
    }
  });
  React.useEffect(() => {
    const abortController = new AbortController();
    const { signal } = abortController;
    const start = (signal2) => __async(this, null, function* () {
      const ach2 = yield payments == null ? void 0 : payments.ach({
        redirectURI,
        transactionId
      }).then((res) => {
        if (signal2 == null ? void 0 : signal2.aborted) {
          return;
        }
        setAch(res);
        return res;
      });
      if (signal2.aborted) {
        yield ach2 == null ? void 0 : ach2.destroy();
      }
    });
    start(signal);
    return () => {
      abortController.abort();
    };
  }, [payments]);
  if (callbacks) {
    for (const callback of Object.keys(callbacks)) {
      ach == null ? void 0 : ach.addEventListener(transformPlaidEventName(callback), callbacks[callback]);
    }
  }
  useEventListener({
    listener: handlePayment,
    type: "click",
    element: buttonRef,
    options: {
      passive: true
    }
  });
  const _a = buttonProps != null ? buttonProps : {}, { isLoading } = _a, props = __objRest(_a, ["isLoading"]);
  const disabled = isLoading || !ach || isSubmitting;
  if (children) {
    return /* @__PURE__ */ React.createElement(PayButton, __spreadProps(__spreadValues({}, props), {
      "aria-disabled": disabled,
      disabled,
      ref: buttonRef,
      type: "button"
    }), children);
  }
  return /* @__PURE__ */ React.createElement(PayButton, __spreadProps(__spreadValues({}, props), {
    "aria-disabled": disabled,
    disabled,
    ref: buttonRef,
    type: "button"
  }), /* @__PURE__ */ React.createElement(SvgIcon, __spreadValues({
    fill: "none",
    height: "1em",
    viewBox: "0 0 36 24",
    width: "1em",
    xmlns: "http://www.w3.org/2000/svg"
  }, svgProps), /* @__PURE__ */ React.createElement("rect", {
    fill: "url(#prefix__paint0_linear)",
    height: 24,
    rx: 4,
    width: 36
  }), /* @__PURE__ */ React.createElement("path", {
    clipRule: "evenodd",
    d: "M18.509 6.16a.89.89 0 00-1.018 0l-6.124 4.285a.848.848 0 00-.325.96.873.873 0 00.833.595h1.75v4.286h-1.75a.866.866 0 00-.875.857c0 .473.392.857.875.857h12.25a.866.866 0 00.875-.857.866.866 0 00-.875-.857h-1.75V12h1.75c.38 0 .717-.24.833-.596a.848.848 0 00-.324-.959L18.509 6.16zm2.116 10.126V12h-5.25v4.286h5.25zM18 7.91l3.395 2.376h-6.79L18 7.91z",
    fill: "#fff",
    fillRule: "evenodd"
  }), /* @__PURE__ */ React.createElement("defs", null, /* @__PURE__ */ React.createElement("linearGradient", {
    gradientUnits: "userSpaceOnUse",
    id: "prefix__paint0_linear",
    x1: 36,
    x2: 0,
    y1: 12,
    y2: 12
  }, /* @__PURE__ */ React.createElement("stop", {
    stopColor: "#01D09E"
  }), /* @__PURE__ */ React.createElement("stop", {
    offset: 1,
    stopColor: "#03E4AE"
  })))), /* @__PURE__ */ React.createElement("span", null, "Pay with Direct debit (ACH)"));
}
export { Ach, Ach as default };
//# sourceMappingURL=ach.es.js.map
